@@ -3,6 +3,22 @@
 #
 # zophExport.pl
 # Jason Geiger, December 2002
+# This file is part of Zoph.
+#
+# Zoph is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# Zoph is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Zoph; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+#
 #
 # zophExport.pl can be used to create static html for your photos in Zoph.
 # This script, like zophImport.pl, is an ugly hack in many ways.
@@ -21,14 +37,16 @@ use File::Copy;
 $| = 1;
 
 # edit these to reflect your database
+my $db_host = 'localhost';  # hostname or hostname:port
 my $db_name = 'zoph';
 my $db_user = 'zoph_rw';
 my $db_pass = 'password';
+my $db_prefix = 'zoph_';
 
 # set this to your image directory
 my $image_dir = '/data/images';
 
-my $version = '0.3.3';
+my $version = '0.5.1';
 
 my $export_dir; # where to export to
 my $format;     # one of zoph, album, bins
@@ -42,6 +60,8 @@ my $album_dirs  = 1;     # create dirs for albums
 my $subalbums  = 1;      # get subalbums for albums
 my $subcategories  = 1;  # get subcats for cats
 
+my $encoding = 'UTF-8';  # default encoding
+
 # what to display
 my $show_date = 1;
 my $show_title = 1;
@@ -83,7 +103,7 @@ if ($#ARGV < 0) {
     exit(0);
 }
 
-my $dbh = DBI->connect("DBI:mysql:$db_name", $db_user, $db_pass);
+my $dbh = DBI->connect("DBI:mysql:$db_name:$db_host", $db_user, $db_pass);
 
 GetOptions(
     'help' => sub { printUsage(); exit(0); },
@@ -179,6 +199,7 @@ sub export {
             print "Reading in language file\n";
             # don't really need most strings but get them all
             while (<LANG>) {
+                $encoding = $1 if /"charset"=>"([^"]*)/;
                 next if /^#/;
                 my ($en, $trans) = split '=';
                 $lang_hash{$en} = $trans;
@@ -188,6 +209,7 @@ sub export {
         else {
             warn "Could not open language file: $language_file\n";
         }
+        print "Using $encoding encoding\n";
     }
 
     $export_dir =~ s/\/$//;
@@ -264,7 +286,7 @@ sub export {
 # Generates a sql statement to look up photos.
 #
 sub generateSql {
-    my $from = "photos as ph";
+    my $from = $db_prefix . "photos as ph";
     my $where = "";
     my $field;
     foreach $field (keys %fieldHash) {
@@ -283,7 +305,7 @@ sub generateSql {
 
     #@albums = split(/\s*,\s*/, join(',', @albums)); I have albums with commas
     if (@albums) {
-        $from .= ", photo_albums as pa";
+        $from .= ", " . $db_prefix . "photo_albums as pa";
         if ($where) { $where .= " and "; }
 
         my $prev = 0;
@@ -295,7 +317,7 @@ sub generateSql {
 
     @categories = split(/\s*,\s*/, join(',', @categories));
     if (@categories) {
-        $from .= ", photo_categories as pc";
+        $from .= ", " . $db_prefix . "photo_categories as pc";
         if ($where) { $where .= " and "; }
 
         my $prev = 0;
@@ -308,7 +330,7 @@ sub generateSql {
 
     @people = split(/\s*,\s*/, join(',', @people));
     if (@people) {
-        $from .= ", photo_people as pp";
+        $from .= ", " . $db_prefix . "photo_people as pp";
         if ($where) { $where .= " and "; }
 
         my $prev = 0;
@@ -391,7 +413,7 @@ sub lookupPersonId {
 
     my ($first, $last) = split / +/, $person;
     my $query =
-        "select person_id from people where " .
+        "select person_id from " . $db_prefix . "people where " .
         "lower(first_name) = " .  $dbh->quote($first) . " and " .
         "lower(last_name) = " .  $dbh->quote($last);
 
@@ -414,7 +436,7 @@ sub lookupPlaceId {
     $place = lc($place);
 
     my $query =
-        "select place_id from places where " .
+        "select place_id from " . $db_prefix . "places where " .
         "lower(title) = " .  $dbh->quote($place);
 
     my @row_array = $dbh->selectrow_array($query);
@@ -484,8 +506,8 @@ sub getId {
     my ($value, $field, $table) = @_;
 
     my $sql =
-        "select $field" . "_id from $table where lower($field) = " .
-        $dbh->quote(lc($value));
+        "select $field" . "_id from " . $db_prefix . "$table " .
+        "where lower($field) = " .  $dbh->quote(lc($value));
 
     my $sth = $dbh->prepare($sql);
     $sth->execute() or die "Error: Could not execute sql: $sql\n";
@@ -504,9 +526,9 @@ sub getId {
 # Mostly for getting a name using an id.
 #
 sub getName {
-    my ($id, $field, $name, $table, $supress) = @_;
+    my ($id, $field, $name, $table, $suppress) = @_;
 
-    my $sql = "select $name from $table where $field = $id";
+    my $sql = "select $name from " . $db_prefix . "$table where $field = $id";
     #print "$sql\n";
 
     my $sth = $dbh->prepare($sql);
@@ -514,7 +536,7 @@ sub getName {
 
     my $val = $sth->fetchrow_array();
 
-    if (not $val and not $supress) {
+    if (not $val and not $suppress) {
         print "Error: $field not found: $id\n";
     }
 
@@ -528,7 +550,7 @@ sub getName {
 sub getRelatedIds {
     my ($id, $field, $table) = @_;
 
-    my $sql = "select $field from $table where photo_id = $id";
+    my $sql = "select $field from " . $db_prefix . "$table where photo_id = $id";
 
     my $sth = $dbh->prepare($sql);
     $sth->execute() or die "Error: Could not execute sql: $sql\n";
@@ -545,8 +567,8 @@ sub getChildrenIds {
     my ($id, $field, $table) = @_;
 
     my $sql =
-        "select $field" . "_id from $table where parent_" . $field . "_id = " .
-        $dbh->quote($id);
+        "select $field" . "_id from " . $db_prefix . "$table " .
+        "where parent_" . $field . "_id = " .  $dbh->quote($id);
 
     my $sth = $dbh->prepare($sql);
     $sth->execute() or die "Error: Could not execute sql: $sql\n";
@@ -567,8 +589,8 @@ sub getAncestorNames {
     my ($id, $field, $table) = @_;
 
     my $sql =
-        "select parent_$field" . "_id, $field from $table where $field" . "_id = " .
-        $dbh->quote($id);
+        "select parent_$field" . "_id, $field from " . $db_prefix . "$table " .
+        "where $field" . "_id = " .  $dbh->quote($id);
 
     my $sth = $dbh->prepare($sql);
     $sth->execute() or die "Error: Could not execute sql: $sql\n";
@@ -702,7 +724,7 @@ sub binsExport {
     open IMAGE_XML, ">$export_path/$name.xml"
         or die "Could not open $name.xml file\n";
 
-    print IMAGE_XML "<?xml version=\"1.0\" encoding=\"UTF-8\"?><image>\n";
+    print IMAGE_XML "<?xml version=\"1.0\" encoding=\"$encoding\"?><image>\n";
     print IMAGE_XML "   <description>\n";
 
     if ($show_description and $photo_hash->{'description'}) {
@@ -936,7 +958,7 @@ sub makeAlbumXml {
 
     if (open ALBUM_XML, ">$path/album.xml") {
         print ALBUM_XML <<"(XML)";
-<?xml version="1.0" encoding="UTF-8"?>
+<?xml version="1.0" encoding="$encoding"?>
 <album>
   <description>
     <field name="longdesc">
