@@ -2,29 +2,50 @@
 
 /*
  * A photo album class corresponding to the album table.
+ *
+ * This file is part of Zoph.
+ *
+ * Zoph is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ * 
+ * Zoph is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * You should have received a copy of the GNU General Public License
+ * along with Zoph; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
+
 class album extends zoph_tree_table {
 
     var $photo_count;
 
     function album($id = 0) {
-        parent::zoph_table("albums", array("album_id"));
+        parent::zoph_table("albums", array("album_id"), array("album"));
         $this->set("album_id", $id);
     }
 
     function lookup($user = null) {
         $id = $this->get("album_id");
+        if(!is_numeric($id)) { die("album_id must be numeric"); }
         if (!$id) { return; }
 
         if ($user && !$user->is_admin()) {
             $sql =
-                 "select a.* from albums as a, album_permissions as ap " .
+                 "select a.* from "  .
+                 DB_PREFIX . "albums as a, " .
+                 DB_PREFIX . "album_permissions as ap " .
                  "where ap.album_id = '" . escape_string($id) . "'" .
                  " and ap.user_id = '" . escape_string($user->get("user_id")) .
                  "' and ap.album_id = a.album_id";
         }
         else {
-            $sql = "select * from albums where album_id = " . $id;
+            $sql =
+                "select * from " . DB_PREFIX . "albums " .
+                "where album_id = " . escape_string($id);
         }
 
         return parent::lookup($sql);
@@ -32,6 +53,13 @@ class album extends zoph_tree_table {
 
     function delete() {
         parent::delete(array("photo_albums", "album_permissions"));
+        $users = get_records("user", "user_id", array("lightbox_id" => $this->get("album_id")));
+        if ($users) {
+          foreach ($users as $user) {
+            $user->set_fields(array("lightbox_id" => "null"));
+            $user->update();
+          }
+        }
     }
 
     function get_children($user = null) {
@@ -41,8 +69,9 @@ class album extends zoph_tree_table {
 
         if ($user && !$user->is_admin()) {
             $sql =
-                 "select a.album_id, a.album, a.album_description " .
-                 "from albums as a, album_permissions as ap " .
+                 "select a.album_id, a.album, a.album_description from " .
+                 DB_PREFIX . "albums as a, " .
+                 DB_PREFIX . "album_permissions as ap " .
                  "where a.parent_album_id = '" . escape_string($id) . "'" .
                  " and ap.user_id = '" . escape_string($user->get("user_id")) .
                  "' and ap.album_id = a.album_id" .
@@ -50,9 +79,9 @@ class album extends zoph_tree_table {
         }
         else {
             $sql =
-                 "select album_id, album, album_description " .
-                 "from albums where parent_album_id = $id " .
-                 "order by album";
+                 "select album_id, album, album_description from " .
+                 DB_PREFIX . "albums " .
+                 "where parent_album_id = $id order by album";
         }
 
         $this->children = get_records_from_query("album", $sql);
@@ -68,9 +97,10 @@ class album extends zoph_tree_table {
 
         if ($user && !$user->is_admin()) {
             $sql =
-                "select count(*) " .
-                "from photo_albums as pa, photos as p, " .
-                "album_permissions as ap " .
+                "select count(*) from " .
+                DB_PREFIX . "photo_albums as pa, " .
+                DB_PREFIX . "photos as p, " .
+                DB_PREFIX . "album_permissions as ap " .
                 "where pa.album_id = $id" .
                 " and ap.user_id = '" . escape_string($user->get("user_id")) .
                 "' and ap.album_id = pa.album_id" .
@@ -79,7 +109,8 @@ class album extends zoph_tree_table {
         }
         else {
             $sql =
-                "select count(*) from photo_albums " .
+                "select count(*) from " .
+                DB_PREFIX . "photo_albums " .
                 "where album_id = '" .  escape_string($id) . "'";
         }
 
@@ -97,9 +128,10 @@ class album extends zoph_tree_table {
 
         if ($user && !$user->is_admin()) {
             $sql =
-                "select count(distinct pa.photo_id) " .
-                "from photo_albums as pa, photos as p, " .
-                "album_permissions as ap " .
+                "select count(distinct pa.photo_id) from " .
+                DB_PREFIX . "photo_albums as pa, " .
+                DB_PREFIX . "photos as p, " .
+                DB_PREFIX . "album_permissions as ap " .
                 "where ap.user_id = '" . escape_string($user->get("user_id")) .
                 "' and ap.album_id = pa.album_id " .
                 " and pa.photo_id = p.photo_id " .
@@ -111,7 +143,8 @@ class album extends zoph_tree_table {
         }
         else {
             $sql =
-                "select count(distinct pa.photo_id) from photo_albums pa";
+                "select count(distinct pa.photo_id) from " .
+                DB_PREFIX . "photo_albums pa ";
                 "where ($id_values)";
 
             if ($id_constraint) {
@@ -156,27 +189,41 @@ function get_albums($user = null) {
 
     if ($user && !$user->is_admin()) {
         $sql =
-             "select a.* from albums as a, album_permissions as ap " .
+             "select a.* from " .
+             DB_PREFIX . "albums as a, " .
+             DB_PREFIX . "album_permissions as ap " .
              "where ap.user_id = '" . escape_string($user->get("user_id")) .
              "' and ap.album_id = a.album_id " .
              "order by a.album";
     }
     else {
-        $sql = "select * from albums order by album";
+        $sql = "select * from " . DB_PREFIX . "albums order by album";
     }
 
     return get_records_from_query("album", $sql);
 }
 
+function get_newer_albums($user_id, $date = null) {
+    $sql = "select a.* from " .
+        DB_PREFIX . "albums as a, " .
+        DB_PREFIX . "album_permissions as ap " .
+        "where ap.user_id = '" . escape_string($user_id) .
+        "' and ap.album_id = a.album_id " .
+        "and ap.changedate > '" . escape_string($date) . "' " .
+        "order by a.album_id";
+
+    return get_records_from_query("album", $sql);
+}
+
 function get_album_count($user = null) {
 
     if ($user && !$user->is_admin()) {
         $sql =
-            "select count(*) from album_permissions where user_id = '" .
-            escape_string($user->get("user_id")) . "'";
+            "select count(*) from " . DB_PREFIX . "album_permissions " .
+            "where user_id = '" . escape_string($user->get("user_id")) . "'";
     }
     else {
-        $sql = "select count(*) from albums";
+        $sql = "select count(*) from " . DB_PREFIX . "albums";
     }
 
     return get_count_from_query($sql);
@@ -196,20 +243,25 @@ function get_popular_albums($user) {
 
     if ($user && !$user->is_admin()) {
         $sql =
-            "select al.*, count(*) as count " .
-            "from albums as al, photo_albums as pa, " .
-            "album_permissions as ap " .
-            "where ap.user_id = '" . escape_string($user->get("user_id")) .
-            "' and ap.album_id = pa.album_id" .
-            " and pa.album_id = al.album_id " .
+            "select al.*, count(distinct ph.photo_id) as count from " .
+            DB_PREFIX . "albums as al, " .
+            DB_PREFIX . "photos as ph, " .
+            DB_PREFIX . "photo_albums as pa, " .
+            DB_PREFIX . "album_permissions as ap " .
+            "where ap.user_id = '" . escape_string($user->get("user_id")) . "'" .
+            " and ap.album_id = pa.album_id" .
+            " and pa.album_id = al.album_id" .
+            " and pa.photo_id = ph.photo_id" .
+            " and ap.access_level >= ph.level " .
             "group by al.album_id " .
             "order by count desc, al.album " .
             "limit 0, $TOP_N";
     }
     else {
         $sql =
-            "select al.*, count(*) as count " .
-            "from albums as al, photo_albums as pa " .
+            "select al.*, count(*) as count from " .
+            DB_PREFIX . "albums as al, " .
+            DB_PREFIX . "photo_albums as pa " .
             "where pa.album_id = al.album_id " .
             "group by al.album_id " .
             "order by count desc, al.album " .
